==> apache-brpc-1.2.0-incubating-src.tar.gz: apache-brpc-1.2.0-incubating-src/community/oncall.md <==
# 值周工程师的职责如下

## 1. 每天查看github上brpc项目待处理的Pull Request和Issue列表，负责问题的处理
  *  包括标记issue，回复issue，关闭issue等；
  *  判断issue是否是长期Issue，如果是则标记为Pending
  *  判断Issue的类型，例如bug，enhancement, discussion等
  *  把issue分配到熟悉该模块的贡献者(可在微信群里询问谁来负责)

## 2. 轮值时间为一周
  *  即从周日早上到下周六晚上

## 3. 轮值结束需要
  *  编写值周report，并发送到dev@brpc.apache.org邮件群中
  *  提醒下一位轮值同学

## 4. 值周顺序如下
  * 朱佳顺 @zyearn
  * 李磊 @lorinlee
  * 王伟冰 @wwbmmm
  * 蔡道进 @cdjingit
  * 何磊 @TousakaRin
  * 刘帅 @serverglen

## 5. 值周记录如下

|  时间(月/日/年）   | 值周人  | 值周report|
|  ----  | ----  | --- |
|   | 朱佳顺 |
| 06/21/2021 to 06/27/2021 | 李磊 | https://lists.apache.org/thread.html/rc9eb911bc6465c16bd8bb14f9d1f7c9548e13759101f43cf0300908a%40%3Cdev.brpc.apache.org%3E
| 06/28/2021 to 07/04/2021 | 蔡道进 | https://lists.apache.org/thread.html/r23992a4f958bea5b28b9b87a09c60790dae8d5d28f2c49aded3f1760%40%3Cdev.brpc.apache.org%3E
| 07/05/2021 - 07/12/2021  | 何磊 | https://lists.apache.org/thread.html/r3f67bc42ecdc07b25c39aedaf30aeae79039aa1cc3e6ad99364c8178%40%3Cdev.brpc.apache.org%3E
| 08/16/2021 - 08/22/2021  | 朱佳顺 | https://lists.apache.org/thread.html/rc03364574b40e4e9bb8112eae0500589d632011f535a4f0747c4ce5f%40%3Cdev.brpc.apache.org%3E
| 08/23/2021 - 08/29/2021  | 李磊 | https://lists.apache.org/thread.html/r10522af87df62aa0aa48f5a279cef219db1917048108cb744e53772e%40%3Cdev.brpc.apache.org%3E
| 08/30/2021 - 09/05/2021  | 蔡道进 |https://lists.apache.org/thread.html/r6e9846a17464581528280b43d835000da78ee700d2fa195cb92d2353%40%3Cdev.brpc.apache.org%3E
| 09/06/2021 - 09/12/2021  | 何磊 | https://lists.apache.org/thread.html/ra10e10abca213e0e5e797a74af8a9c8810e54fd1543c108bf03a56e5%40%3Cdev.brpc.apache.org%3E
| 09/20/2021 - 09/26/2021  | 李磊 | https://lists.apache.org/thread.html/r19c08874ad681edbc82526a09b34d3ccabe7cf168ed91935575ff557%40%3Cdev.brpc.apache.org%3E
| 09/27/2021 - 10/03/2021  | 蔡道进 | https://lists.apache.org/thread.html/re3391d87f2e2aba55986b96b18ca375f07840bac67249fced2f851f5%40%3Cdev.brpc.apache.org%3E
| 13/12/2021 - 19/12/2021  | 蔡道进 | https://lists.apache.org/thread/mvclsy79859mrbdso1xzm6y7yz3lg6w0
| 01/24/2022 - 02/06/2022  | 王伟冰 | https://lists.apache.org/thread/ttgqnw4hfw0qnb7swvnn2kxb5b9hkdbo
| 04/10/2022 - 04/16/2022  | 刘帅 | https://lists.apache.org/thread/0l67lqnw0l6rgfwkvhrc168prwr7fp60
| 04/17/2022 - 04/24/2022  | 朱佳顺| https://lists.apache.org/thread/xwkpyonndgtp8tq4c9v4yfowqx7fg9gl
| 04/25/2022 - 05/01/2022  | 李磊 | https://lists.apache.org/thread/cx7t1glptr7x7posxstsb1691h4m4mbl
| 05/02/2022 - 05/15/2022  | 王伟冰 | https://lists.apache.org/thread/tgyqkhh6fqgyzcn5d56kt46hk978wogx
| 06/06/2022 - 06/12/2022  | 何磊 | https://lists.apache.org/thread/s19p7ygnsj0bknfjvrh0wlf1mbgstxbk
| 06/13/2022 - 06/19/2022  | 刘帅 | https://lists.apache.org/thread/tvqjyz6rh7jb1zcclx0lh6zrcsf9ykxr

==> apache-brpc-1.3.0-incubating-src.tar.gz: apache-brpc-1.3.0-incubating-src/community/oncall.md <==
# 值周工程师的职责如下

## 1. 每天查看github上brpc项目待处理的Pull Request和Issue列表，负责问题的处理
  *  包括标记issue，回复issue，关闭issue等；
  *  判断issue是否是长期Issue，如果是则标记为Pending
  *  判断Issue的类型，例如bug，enhancement, discussion等
  *  把issue分配到熟悉该模块的贡献者(可在微信群里询问谁来负责)

## 2. 轮值时间为一周
  *  即从周日早上到下周六晚上

## 3. 轮值结束需要
  *  编写值周report，并发送到dev@brpc.apache.org邮件群中
  *  提醒下一位轮值同学

## 4. 值周顺序如下
  * 朱佳顺 @zyearn
  * 李磊 @lorinlee
  * 王伟冰 @wwbmmm
  * 蔡道进 @cdjingit
  * 何磊 @TousakaRin
  * 刘帅 @serverglen

## 5. 值周记录如下

|  时间(月/日/年）   | 值周人  | 值周report|
|  ----  | ----  | --- |
|   | 朱佳顺 |
| 06/21/2021 to 06/27/2021 | 李磊 | https://lists.apache.org/thread.html/rc9eb911bc6465c16bd8bb14f9d1f7c9548e13759101f43cf0300908a%40%3Cdev.brpc.apache.org%3E
| 06/28/2021 to 07/04/2021 | 蔡道进 | https://lists.apache.org/thread.html/r23992a4f958bea5b28b9b87a09c60790dae8d5d28f2c49aded3f1760%40%3Cdev.brpc.apache.org%3E
| 07/05/2021 - 07/12/2021  | 何磊 | https://lists.apache.org/thread.html/r3f67bc42ecdc07b25c39aedaf30aeae79039aa1cc3e6ad99364c8178%40%3Cdev.brpc.apache.org%3E
| 08/16/2021 - 08/22/2021  | 朱佳顺 | https://lists.apache.org/thread.html/rc03364574b40e4e9bb8112eae0500589d632011f535a4f0747c4ce5f%40%3Cdev.brpc.apache.org%3E
| 08/23/2021 - 08/29/2021  | 李磊 | https://lists.apache.org/thread.html/r10522af87df62aa0aa48f5a279cef219db1917048108cb744e53772e%40%3Cdev.brpc.apache.org%3E
| 08/30/2021 - 09/05/2021  | 蔡道进 |https://lists.apache.org/thread.html/r6e9846a17464581528280b43d835000da78ee700d2fa195cb92d2353%40%3Cdev.brpc.apache.org%3E
| 09/06/2021 - 09/12/2021  | 何磊 | https://lists.apache.org/thread.html/ra10e10abca213e0e5e797a74af8a9c8810e54fd1543c108bf03a56e5%40%3Cdev.brpc.apache.org%3E
| 09/20/2021 - 09/26/2021  | 李磊 | https://lists.apache.org/thread.html/r19c08874ad681edbc82526a09b34d3ccabe7cf168ed91935575ff557%40%3Cdev.brpc.apache.org%3E
| 09/27/2021 - 10/03/2021  | 蔡道进 | https://lists.apache.org/thread.html/re3391d87f2e2aba55986b96b18ca375f07840bac67249fced2f851f5%40%3Cdev.brpc.apache.org%3E
| 12/13/2021 - 12/19/2021  | 蔡道进 | https://lists.apache.org/thread/mvclsy79859mrbdso1xzm6y7yz3lg6w0
| 01/24/2022 - 02/06/2022  | 王伟冰 | https://lists.apache.org/thread/ttgqnw4hfw0qnb7swvnn2kxb5b9hkdbo
| 04/10/2022 - 04/16/2022  | 刘帅 | https://lists.apache.org/thread/0l67lqnw0l6rgfwkvhrc168prwr7fp60
| 04/17/2022 - 04/24/2022  | 朱佳顺| https://lists.apache.org/thread/xwkpyonndgtp8tq4c9v4yfowqx7fg9gl
| 04/25/2022 - 05/01/2022  | 李磊 | https://lists.apache.org/thread/cx7t1glptr7x7posxstsb1691h4m4mbl
| 05/02/2022 - 05/15/2022  | 王伟冰 | https://lists.apache.org/thread/tgyqkhh6fqgyzcn5d56kt46hk978wogx
| 06/06/2022 - 06/12/2022  | 何磊 | https://lists.apache.org/thread/s19p7ygnsj0bknfjvrh0wlf1mbgstxbk
| 06/13/2022 - 06/19/2022  | 刘帅 | https://lists.apache.org/thread/tvqjyz6rh7jb1zcclx0lh6zrcsf9ykxr
| 07/25/2022 - 07/31/2022  | 王伟冰 | https://lists.apache.org/thread/83scwkkfxrp6kkkoltbrn1fthfy3w0qz
| 08/08/2022 - 08/14/2022  | 何磊 | https://lists.apache.org/thread/jj16rzfh34yrt6o0xqfdz9wtdtzxzswq
| 08/15/2022 - 08/21/2022  | 刘帅 | https://lists.apache.org/thread/jp69sm7c8fs3dkdd828qk0fsojqwwz6h
| 09/05/2022 - 09/12/2022  | 王伟冰 | https://lists.apache.org/thread/4jjk2hxw9s2wskccclqb8fvpqxqffnlb
| 09/12/2022 - 09/18/2022  | 蔡道进| https://lists.apache.org/thread/8mo7zl0l2yrd8tp4v3kx86rnlyfk6wz4
| 09/19/2022 - 09/25/2022  | 何磊 | https://lists.apache.org/thread/qlkr7cmwow3ob47dt80tpx0zrgzg7bdm
| 09/26/2022 - 10/09/2022  | 刘帅 | https://lists.apache.org/thread/b0lwr8wyflmhqlnf0kkh1j30tgt5qw54
